Equivalent

Trait Equivalent 

pub trait Equivalent: Any + Debug {
    // Required methods
    fn equals(&self, other: &dyn Equivalent) -> bool;
    fn as_any(&self) -> &dyn Any;
}
Trait for types that can be compared for equality and downcasted. Used primarily for tracking removable items in the data stores.

Required Methods

fn equals(&self, other: &dyn Equivalent) -> bool

Checks if this item equals another Equivalent item

fn as_any(&self) -> &dyn Any

Allows downcasting to concrete type

Implementations on Foreign Types

Source

impl Equivalent for Value

Source

fn equals(&self, other: &dyn Equivalent) -> bool

Source

fn as_any(&self) -> &dyn Any

Source

impl Equivalent for PathBuf

Source

fn equals(&self, other: &dyn Equivalent) -> bool

Source

fn as_any(&self) -> &dyn Any

Implementors